@@ -77,13 +77,19 @@ async def prepare_key(arr):
 
 
 async def encrypt_key(a, key):
-    return sum(((await aes_cbc_encrypt_a32(a[i:i + 4]), key)
-                async for i in range(0, len(a), 4)), ())
+    return sum(
+        (
+            (await aes_cbc_encrypt_a32(a[i:i + 4], key)) async for i in  AsyncIterator(range(0, len(a), 4))
+        ), ()
+    )
 
 
 async def decrypt_key(a, key):
-    return sum(((await aes_cbc_decrypt_a32(a[i:i + 4]), key)
-                for i in range(0, len(a), 4)), ())
+    return sum(
+        (
+            (await aes_cbc_decrypt_a32(a[i:i + 4], key)) async for i in AsyncIterator(range(0, len(a), 4))
+        ), ()
+    )
 
 
 async def encrypt_attr(attr, key):
@@ -184,3 +190,19 @@ def make_id(length):
     for i in range(length):
         text += random.choice(possible)
     return text
+
+
+class AsyncIterator:
+    def __init__(self, seq):
+        self.iter = iter(seq)
+
+    def __aiter__(self):
+        return self
+
+    async def __anext__(self):
+        try:
+            return next(self.iter)
+        except StopIteration:
+            raise StopAsyncIteration
+
+            
